@@ -16,6 +16,17 @@ from starflow.logger import get_configured_logger
 from starflow.schemas import DeployModeType, DisplayResultFileType
 from starflow.exceptions.exceptions import InvalidPieceOutputError
 
+from pydantic import BaseModel, Field
+
+class BaseBranchOutputModel(BaseModel):
+    """
+    Branch Piece Output Model
+    """
+
+    branch_main: bool = Field(
+        default=True,
+        description="Main branch selected",
+    )
 
 class BasePiece(metaclass=abc.ABCMeta):
 
@@ -54,7 +65,7 @@ class BasePiece(metaclass=abc.ABCMeta):
         # Piece task attributes
         self.task_id = task_id
         self.dag_id = dag_id
-        self.deploy_mode = deploy_mode
+        self.deploy_mode = "k8s"
 
         # Logger
         self.logger = get_configured_logger(f"{self.__class__.__name__ }-{self.task_id}")
@@ -120,15 +131,12 @@ class BasePiece(metaclass=abc.ABCMeta):
             NotImplementedError: _description_
         """
         self.upstream_tasks_data = dict()
-        if self.deploy_mode == "k8s":
-            upstream_tasks_ids = ast.literal_eval(os.getenv("AIRFLOW_UPSTREAM_TASKS_IDS", str(list())))
-            for tid in upstream_tasks_ids:
-                self.upstream_tasks_data[tid] = dict()
-                self.upstream_tasks_data[tid]["results"] = self.workflow_shared_storage_path + f"/{tid}/results"
-                with open(f"{self.workflow_shared_storage_path}/{tid}/xcom/return.json") as f:
-                    self.upstream_tasks_data[tid]["xcom"] = json.load(f)
-        else:
-            raise NotImplementedError(f"Get upstream XCOM not implemented for deploy_mode=={self.deploy_mode}")
+        upstream_tasks_ids = ast.literal_eval(os.getenv("AIRFLOW_UPSTREAM_TASKS_IDS", str(list())))
+        for tid in upstream_tasks_ids:
+            self.upstream_tasks_data[tid] = dict()
+            self.upstream_tasks_data[tid]["results"] = self.workflow_shared_storage_path + f"/{tid}/results"
+            with open(f"{self.workflow_shared_storage_path}/{tid}/xcom/return.json") as f:
+                self.upstream_tasks_data[tid]["xcom"] = json.load(f)
 
     def validate_and_get_env_secrets(self, piece_secrets_model: pydantic.BaseModel = None):
         """
@@ -199,37 +207,19 @@ class BasePiece(metaclass=abc.ABCMeta):
         Raises:
             NotImplementedError: _description_
         """
-        if self.deploy_mode in ["local-python"]:
-            self.airflow_context['ti'].xcom_push(key=self.task_id, value=xcom_obj)
 
-        elif self.deploy_mode == "local-compose":
-            file_path = Path('/airflow/xcom/return.out')
-            file_path.parent.mkdir(parents=True, exist_ok=True)
-            with open(str(file_path), 'wb') as fp:
-                pickle.dump(xcom_obj, fp)
+        # In Kubernetes, return XCom must be stored in /airflow/xcom/return.json
+        # https://airflow.apache.org/docs/apache-airflow-providers-cncf-kubernetes/stable/pieces.html#how-does-xcom-work
+        file_path = Path('/airflow/xcom/return.json')
+        file_path.parent.mkdir(parents=True, exist_ok=True)
+        with open(str(file_path), 'w') as fp:
+            json.dump(xcom_obj, fp)
 
-        elif self.deploy_mode == "local-bash":
-            # For our extended BashOperator, return XCom must be stored in /opt/mnt/fs/tmp/xcom_output.json
-            file_path = Path("/opt/mnt/fs/tmp/xcom_output.json")
-            file_path.parent.mkdir(parents=True, exist_ok=True)
-            with open(str(file_path), 'w') as fp:
-                json.dump(xcom_obj, fp, indent=4)
+        # Also store it at /home/workflow_shared_data/{self.task_id}/xcom/return.json for convenience
+        file_path = self.xcom_path + "/return.json"
+        with open(file_path, 'w') as fp:
+            json.dump(xcom_obj, fp)
 
-        elif self.deploy_mode in ["k8s", "local-k8s", "local-k8s-dev"]:
-            # In Kubernetes, return XCom must be stored in /airflow/xcom/return.json
-            # https://airflow.apache.org/docs/apache-airflow-providers-cncf-kubernetes/stable/pieces.html#how-does-xcom-work
-            file_path = Path('/airflow/xcom/return.json')
-            file_path.parent.mkdir(parents=True, exist_ok=True)
-            with open(str(file_path), 'w') as fp:
-                json.dump(xcom_obj, fp)
-
-            # Also store it at /home/workflow_shared_data/{self.task_id}/xcom/return.json for convenience
-            file_path = self.xcom_path + "/return.json"
-            with open(file_path, 'w') as fp:
-                json.dump(xcom_obj, fp)
-
-        else:
-            raise NotImplementedError("deploy mode not accepted for xcom push")
 
     def run_piece_function(
         self,
