@@ -28,6 +28,7 @@ class starflowKubernetesPodOperator(KubernetesPodOperator):
         repository_url: str,
         repository_version: str,
         workspace_id: int,
+        username: Optional[str] = None,
         piece_input_kwargs: Optional[Dict] = None,
         workflow_shared_storage: WorkflowSharedStorage = None,
         container_resources: Optional[Dict] = None,
@@ -43,6 +44,7 @@ class starflowKubernetesPodOperator(KubernetesPodOperator):
         self.piece_input_kwargs = piece_input_kwargs
         self.workflow_shared_storage = workflow_shared_storage
         self.piece_source_image = k8s_operator_kwargs["image"]
+        self.username_var = username
 
         # Environment variables
         pod_env_vars = {
@@ -56,28 +58,30 @@ class starflowKubernetesPodOperator(KubernetesPodOperator):
             "STARFLOW_WORKFLOW_SHARED_STORAGE": workflow_shared_storage.model_dump_json() if workflow_shared_storage else "",
             "AIRFLOW_CONTEXT_EXECUTION_DATETIME": "{{ dag_run.logical_date | ts_nodash }}",
             "AIRFLOW_CONTEXT_DAG_RUN_ID": "{{ run_id }}",
-            "OPEN_ID_SERVER_URL": os.environ['OPEN_ID_SERVER_URL'],
-            "OPEN_ID_CLIENT_ID": os.environ['OPEN_ID_CLIENT_ID'],
-            "OPEN_ID_REALM_NAME": os.environ['OPEN_ID_REALM_NAME'],
-            "OPEN_ID_CLIENT_SECRET": os.environ['OPEN_ID_CLIENT_SECRET'],
-            "URL_PUT_START_DOCK": os.environ['URL_PUT_START_DOCK'],
-            "URL_GET_FLEET_MOVEMENT_CALCULATION": os.environ['URL_GET_FLEET_MOVEMENT_CALCULATION'],
-            "URL_GET_FLEET_MINING_CALCULATION": os.environ['URL_GET_FLEET_MINING_CALCULATION'],
-            "URL_PUT_LOAD_CARGO": os.environ['URL_PUT_LOAD_CARGO'],
-            "URL_PUT_LOAD_AMMO": os.environ['URL_PUT_LOAD_AMMO'],
-            "URL_PUT_LOAD_FUEL": os.environ['URL_PUT_LOAD_FUEL'],
-            "URL_PUT_UNLOAD_CARGO": os.environ['URL_PUT_UNLOAD_CARGO'],
-            "URL_PUT_UNLOAD_AMMO": os.environ['URL_PUT_UNLOAD_AMMO'],
-            "URL_PUT_UNLOAD_FUEL": os.environ['URL_PUT_UNLOAD_FUEL'],
-            "URL_PUT_START_MINING": os.environ['URL_PUT_START_MINING'],
-            "URL_PUT_STOP_MINING": os.environ['URL_PUT_STOP_MINING'],
-            "URL_PUT_START_DOCK": os.environ['URL_PUT_START_DOCK'],
-            "URL_PUT_START_UNDOCK": os.environ['URL_PUT_START_UNDOCK'],
-            "URL_PUT_START_SUBWARP": os.environ['URL_PUT_START_SUBWARP'],
-            "URL_PUT_START_EXITSUBWARP": os.environ['URL_PUT_START_EXITSUBWARP'],
-            "URL_PUT_START_WARP": os.environ['URL_PUT_START_WARP'],
-            "URL_PUT_START_EXITWARP": os.environ['URL_PUT_START_EXITWARP'],
-            "URL_GET_LIST_FLEET": os.environ['URL_GET_LIST_FLEET']
+            # "OPEN_ID_SERVER_URL": os.environ['OPEN_ID_SERVER_URL'],
+            # "OPEN_ID_CLIENT_ID": os.environ['OPEN_ID_CLIENT_ID'],
+            # "OPEN_ID_REALM_NAME": os.environ['OPEN_ID_REALM_NAME'],
+            # "OPEN_ID_CLIENT_SECRET": os.environ['OPEN_ID_CLIENT_SECRET'],
+            # "URL_PUT_START_DOCK": os.environ['URL_PUT_START_DOCK'],
+            # "URL_GET_FLEET_MOVEMENT_CALCULATION": os.environ['URL_GET_FLEET_MOVEMENT_CALCULATION'],
+            # "URL_GET_FLEET_MINING_CALCULATION": os.environ['URL_GET_FLEET_MINING_CALCULATION'],
+            # "URL_PUT_LOAD_CARGO": os.environ['URL_PUT_LOAD_CARGO'],
+            # "URL_PUT_LOAD_AMMO": os.environ['URL_PUT_LOAD_AMMO'],
+            # "URL_PUT_LOAD_FUEL": os.environ['URL_PUT_LOAD_FUEL'],
+            # "URL_PUT_UNLOAD_CARGO": os.environ['URL_PUT_UNLOAD_CARGO'],
+            # "URL_PUT_UNLOAD_AMMO": os.environ['URL_PUT_UNLOAD_AMMO'],
+            # "URL_PUT_UNLOAD_FUEL": os.environ['URL_PUT_UNLOAD_FUEL'],
+            # "URL_PUT_START_MINING": os.environ['URL_PUT_START_MINING'],
+            # "URL_PUT_STOP_MINING": os.environ['URL_PUT_STOP_MINING'],
+            # "URL_PUT_START_DOCK": os.environ['URL_PUT_START_DOCK'],
+            # "URL_PUT_START_UNDOCK": os.environ['URL_PUT_START_UNDOCK'],
+            # "URL_PUT_START_SUBWARP": os.environ['URL_PUT_START_SUBWARP'],
+            # "URL_PUT_START_EXITSUBWARP": os.environ['URL_PUT_START_EXITSUBWARP'],
+            # "URL_PUT_START_WARP": os.environ['URL_PUT_START_WARP'],
+            # "URL_PUT_START_EXITWARP": os.environ['URL_PUT_START_EXITWARP'],
+            # "URL_GET_LIST_FLEET": os.environ['URL_GET_LIST_FLEET'],
+            # "OPEN_ID_USERNAME_SERVICE_USER": os.environ['OPEN_ID_USERNAME_SERVICE_USER'],
+            # "OPEN_ID_PASSWORD_SERVICE_USER": os.environ['OPEN_ID_PASSWORD_SERVICE_USER']
         }
 
         # Container resources
@@ -96,16 +100,16 @@ class starflowKubernetesPodOperator(KubernetesPodOperator):
         container_resources_obj = k8s.V1ResourceRequirements(**updated_container_resources)
 
         # Extra volume and volume mounts - for DEV mode only
-        volumes_dev, volume_mounts_dev = None, None
-        if self.deploy_mode == 'local-k8s-dev':
-            volumes_dev, volume_mounts_dev = self._make_volumes_and_volume_mounts_dev()
+        # volumes_dev, volume_mounts_dev = None, None
+        # if self.deploy_mode == 'local-k8s-dev':
+        #     volumes_dev, volume_mounts_dev = self._make_volumes_and_volume_mounts_dev()
 
         super().__init__(
             task_id=task_id,
             env_vars=pod_env_vars,
             container_resources=container_resources_obj,
-            volumes=volumes_dev,
-            volume_mounts=volume_mounts_dev,
+            # volumes=volumes_dev,
+            # volume_mounts=volume_mounts_dev,
             **k8s_operator_kwargs
         )
 
@@ -196,12 +200,16 @@ class starflowKubernetesPodOperator(KubernetesPodOperator):
         self.task_id_replaced = self.task_id.lower().replace("_", "-") # doing this because airflow doesn't allow underscores and upper case in mount names and max len is 63
         self.shared_storage_base_mount_path = '/home/shared_storage'
 
-        if not self.workflow_shared_storage or self.workflow_shared_storage.mode.name == 'none':
-            return pod
-        if self.workflow_shared_storage.source.name in ["aws_s3", "gcs"]:
-            pod = self.add_shared_storage_sidecar(pod)
-        elif self.workflow_shared_storage.source.name == "local":
-            pod = self.add_local_shared_storage_volumes(pod)
+        pod.metadata.namespace = "airflow"
+        pod.spec.image_pull_secrets = [k8s.V1LocalObjectReference('ghcr-login-secret')]
+
+        # if not self.workflow_shared_storage or self.workflow_shared_storage.mode.name == 'none':
+        #     return pod
+        # if self.workflow_shared_storage.source.name in ["aws_s3", "gcs"]:
+        #     pod = self.add_shared_storage_sidecar(pod)
+        # elif self.workflow_shared_storage.source.name == "local":
+        #     pod = self.add_local_shared_storage_volumes(pod)
+
         return pod
 
 
@@ -356,7 +364,6 @@ class starflowKubernetesPodOperator(KubernetesPodOperator):
         pod_cp.spec.containers.append(sidecar_container)
         return pod_cp
 
-
     def _get_piece_secrets(
         self,
         repository_url: str,
@@ -434,7 +441,6 @@ class starflowKubernetesPodOperator(KubernetesPodOperator):
             'value_from': None
         })
 
-
     def _update_env_var_value_from_name(self, name: str, value: str):
         for env_var in self.env_vars:
             if env_var.name == name:
@@ -465,17 +471,17 @@ class starflowKubernetesPodOperator(KubernetesPodOperator):
         self._update_piece_kwargs_with_upstream_xcom()
         self._update_env_var_value_from_name(name='STARFLOW_RUN_PIECE_KWARGS', value=str(self.piece_input_kwargs))
 
-        # Add pieces secrets to environment variables
-        piece_secrets = self._get_piece_secrets(
-            repository_url=self.repository_url,
-            repository_version=self.repository_version,
-            piece_name=self.piece_name,
-        )
-        self.env_vars.append({
-            "name": "STARFLOW_PIECE_SECRETS",
-            "value": str(piece_secrets),
-            "value_from": None
-        })
+        # # Add pieces secrets to environment variables
+        # piece_secrets = self._get_piece_secrets(
+        #     repository_url=self.repository_url,
+        #     repository_version=self.repository_version,
+        #     piece_name=self.piece_name,
+        # )
+        # self.env_vars.append({
+        #     "name": "STARFLOW_PIECE_SECRETS",
+        #     "value": str(piece_secrets),
+        #     "value_from": None
+        # })
 
         # Include workflow run subpath from dag run id, taken from context
         dag_id = context["dag_run"].dag_id
@@ -487,6 +493,11 @@ class starflowKubernetesPodOperator(KubernetesPodOperator):
             'value': self.workflow_run_subpath,
             'value_from': None
         })
+        self.env_vars.append({
+            'name': 'OPEN_ID_USERNAME_TARGET',
+            'value': str(self.username_var),
+            'value_from': None
+        })
 
 
     def execute(self, context: Context):
