@@ -32,4 +32,16 @@ def load_piece_models_from_path(pieces_folder_path: str, piece_name: str):
     piece_output_model_class = getattr(piece_model_module, "OutputModel")
     piece_secrets_model_class = getattr(piece_model_module, "SecretsModel", None)
 
-    return piece_input_model_class, piece_output_model_class, piece_secrets_model_class
\ No newline at end of file
+    return piece_input_model_class, piece_output_model_class, piece_secrets_model_class
+
+def load_piece_branch_models_from_path(pieces_folder_path: str, piece_name: str):
+    # Import Operator from mounted volume, then set up piece module and class
+    pieces_folder_path = str(Path(pieces_folder_path).resolve())
+    if pieces_folder_path not in sys.path:
+        sys.path.append(pieces_folder_path)
+
+    importlib.invalidate_caches()
+    piece_model_module = importlib.import_module(f"{piece_name}.models")
+    piece_input_model_class = getattr(piece_model_module, "InputModel")
+
+    return piece_input_model_class
\ No newline at end of file
